# Generated by ariadne-codegen
# Source: ../schema.graphql

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel


class DbUpdatesInput(BaseModel):
    device_updates: Optional[List[Optional["EntityUpdateInput"]]] = Field(
        alias="deviceUpdates", default=None
    )
    group_updates: Optional[List[Optional["EntityUpdateInput"]]] = Field(
        alias="groupUpdates", default=None
    )


class EntityUpdateInput(BaseModel):
    id: str
    path: str
    value: Any
